Setuptools lint command
=======================


This package expose `pylint`_ as a lint command into setup.py.


Installation
------------

This package is published on pypi. You can use pip to install it.

::

    pip install setuptools-lint


Usage
-----

::

    python setup.py lint


For a full list of options, do

::

  python setup.py lint --help

.. _`pylint` : http://pypi.python.org/pypi/pylint
